/*
 *  XpmApplication.cpp
 *  appleevents
 *
 *  Created by Trenton Schulz on 10/31/04.
 *  Copyright 2004 Trolltech AS. All rights reserved.
 *
 */

#include "XpmApplication.h"
#include "XpmViewer.h"
#include <qevent.h>
#include <qurl.h>

const int OpenEventID = QEvent::User + 100;

class OpenEvent : public QCustomEvent
{
public:
    OpenEvent(const QString &fileName) : QCustomEvent(OpenEventID), file(fileName) {}
    QString fileName() const { return file; }
    
private:
    QString file;
};

XpmApplication::XpmApplication(int argc, char *argv[])
    : QApplication(argc, argv), viewer(0)
{
    AEInstallEventHandler(kCoreEventClass, kAEOpenDocuments,
                          XpmApplication::appleEventHandler, 0, false);
}

XpmApplication::~XpmApplication()
{
    AERemoveEventHandler(kCoreEventClass, kAEOpenDocuments,
                         XpmApplication::appleEventHandler, false);
}

OSErr XpmApplication::appleEventHandler(const AppleEvent *ae, AppleEvent *, long)
{
    AEDescList docs;
    if (AEGetParamDesc(ae, keyDirectObject, typeAEList, &docs) == noErr) {
        long cnt = 0;
        AECountItems(&docs, &cnt);
        UInt8 strBuffer[256];
        for (int i = 0; i < cnt; i++) {
            FSRef ref;
            if (AEGetNthPtr(&docs, i+1, typeFSRef, 0, 0, &ref, sizeof(ref), 0) != noErr)
                continue;
            if (FSRefMakePath(&ref, strBuffer, 256) == noErr) {
                OpenEvent event(QString::fromUtf8(reinterpret_cast<char *>(strBuffer)));
                QApplication::sendEvent(qApp, &event);
            }
        }
    }
    return noErr;
}

void XpmApplication::customEvent(QCustomEvent *ev)
{
    if (ev->type() == OpenEventID)
        viewer->loadXpmFile(static_cast<OpenEvent *>(ev)->fileName());
}

void XpmApplication::setXpmViewer(XpmViewer *XpmViewer)
{
    viewer = XpmViewer;
}