/*
 *  XpmViewer.cpp
 *  appleevents
 *
 *  Created by Trenton Schulz on 10/31/04.
 *  Copyright 2004 Trolltech AS. All rights reserved.
 *
 */

#include <qapplication.h>
#include <qaction.h>
#include <qimage.h>
#include <qdragobject.h>
#include <qpainter.h>
#include <qmenubar.h>
#include <qpopupmenu.h>
#include <qstatusbar.h>
#include <qfiledialog.h>
#include "xpmviewer.h"

XpmViewer::XpmViewer(QWidget *parent, const char *name)
    : QMainWindow(parent, name)
{
    QMenuBar *mb = menuBar();
    QPopupMenu *pop = new QPopupMenu(this);
    pop->insertItem(tr("&Open XPM..."), this, SLOT(openXpm()), CTRL + Key_O);
    pop->insertItem(tr("&Quit"), qApp, SLOT(quit()));
    mb->insertItem(tr("&File"), pop);
    statusBar();
    resize(200, 200);
    setAcceptDrops(true);
}

void XpmViewer::loadXpmFile(const QString &fileName)
{
    QImage img(fileName, "XPM");
    currXPM = img;
    if (currXPM.isNull()) {
        resize(200, 200);
        statusBar()->message("Not a valid XPM file");
    } else {
        resize(currXPM.width(), currXPM.height() + statusBar()->height() + 5);
        setCaption(fileName);
    }
    update();
}

void XpmViewer::openXpm()
{
    QString fileName = QFileDialog::getOpenFileName("", "XPM Images (*.xpm)", this, 0,
                                                    tr("Selet an XPM file"));
    if (!fileName.isNull())
        loadXpmFile(fileName);
}

void XpmViewer::paintEvent(QPaintEvent *)
{
    QPainter painter(this);
    if (!currXPM.isNull()) {
        painter.drawPixmap(2, 2, currXPM);
    } else {
        painter.fillRect(rect(), white);
        painter.drawText(0, 100, tr("No current XPM"));
    }
}

void XpmViewer::dropEvent(QDropEvent *de)
{
    QStringList files;
    if (QUriDrag::decodeLocalFiles(de, files)) {
        QStringList::const_iterator it = files.constBegin();
        if (it != files.constEnd())
            loadXpmFile(*it);
    }
    de->accept();
}

void XpmViewer::dragEnterEvent(QDragEnterEvent *dee)
{
    return dee->accept(QUriDrag::canDecode(dee));
}